@@ -82,6 +82,11 @@ class PythonScriptManager(object):
         ('portal_skins', 'custom') # "custom" directory.
     ]
 
+    SEARCHABLE_SCRIPT_TYPES = [
+        'Script (Python)',
+        'Filesystem Script (Python)',
+    ]
+
     def getScriptContainers(self):
         """Yield containers that the scripts should be searched in."""
         for path in self.SEARCHABLE_CONTAINER_PATHS:
@@ -94,7 +99,7 @@ class PythonScriptManager(object):
         """Find scripts in given context."""
         for context in self.getScriptContainers():
             # Find all Script (Python) objects in each container.
-            for item in context.objectValues('Script (Python)'):
+            for item in context.objectValues(self.SEARCHABLE_SCRIPT_TYPES):
                 yield item
 
     def getScriptTitle(self, script):
